"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeMethod = void 0;
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const helpers_1 = require("./helpers");
const prompts_1 = require("@clack/prompts");
const log_1 = require("../../../utils/log");
const picocolors_1 = tslib_1.__importDefault(require("picocolors"));
const makeMethod = async (name) => {
    const apiMethodPath = `./packages/api-client/src/api/${name}`;
    const endpointExists = fs_1.default.existsSync(apiMethodPath);
    let isOverwrite = false;
    if (endpointExists) {
        (0, log_1.log)(`Endpoint ${name} already exists`);
        const shouldOverwrite = await (0, prompts_1.confirm)({
            message: `Do you want to overwrite ${name} enpoint?`
        });
        if (!shouldOverwrite) {
            (0, log_1.log)('Endpoint was not created');
            process.exit(0);
        }
        isOverwrite = true;
    }
    await (0, helpers_1.writeApiMethod)(name, isOverwrite);
    await (0, helpers_1.writeSDKMethod)(name, isOverwrite);
    await (0, helpers_1.writePageMethod)(name);
    (0, prompts_1.intro)(`Endpoint ${name} has been created`);
    (0, log_1.log)('Files created:');
    (0, log_1.log)(`- packages/api-client/src/api/${name}`);
    (0, log_1.log)(`- packages/sdk/src/methods/${name}`);
    (0, log_1.log)('Files updated:');
    (0, log_1.log)('- packages/api-client/src/api/index.ts');
    (0, log_1.log)('- packages/sdk/src/methods/index.ts');
    (0, log_1.log)('- packages/api-client/src/types/api/endpoints.ts');
    (0, log_1.log)(`Run ${picocolors_1.default.green('build')} command to build the project and ${picocolors_1.default.green('dev')} command to start the playground again`);
};
exports.makeMethod = makeMethod;
//# sourceMappingURL=index.js.map