"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPkgManager = void 0;
const tslib_1 = require("tslib");
const prompts_1 = require("@clack/prompts");
const execa_1 = tslib_1.__importDefault(require("execa"));
const utils_1 = require("../utils");
const checkPackageManager = async (packageManager) => {
    try {
        await (0, execa_1.default)(packageManager, ['--version'], { stdio: 'ignore' });
    }
    catch (error) {
        return false;
    }
    return true;
};
const getPkgManager = async (pkgManager) => {
    let packageManager = pkgManager || 'yarn';
    packageManager = await (0, prompts_1.select)({
        message: 'What package manager do you want to use?',
        options: [
            { label: 'NPM', value: 'npm' },
            { label: 'Yarn', value: 'yarn' }
        ]
    });
    const isPackageManagerExists = await checkPackageManager(packageManager);
    if (!isPackageManagerExists) {
        const useAnotherPackageManager = await (0, prompts_1.confirm)({
            message: `Package manager ${packageManager} not found. Do you want to use another package manager?`,
            active: 'Yes'
        });
        if (useAnotherPackageManager) {
            if (packageManager === 'npm') {
                packageManager = 'yarn';
            }
            else {
                packageManager = 'npm';
            }
            return await (0, exports.getPkgManager)(packageManager);
        }
        else {
            (0, utils_1.log)('Please install package manager and try again.');
            process.exit(1);
        }
    }
    return packageManager;
};
exports.getPkgManager = getPkgManager;
//# sourceMappingURL=getPackageManager.js.map